@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     AuthMechanismValueType,
     AuthTypeValueType,
@@ -191,7 +193,7 @@ CertificateTypeDef = TypedDict(
         "CertificateIdentifier": str,
         "CertificateCreationDate": datetime,
         "CertificatePem": str,
-        "CertificateWallet": Union[bytes, IO[bytes]],
+        "CertificateWallet": Union[bytes, IO[bytes], StreamingBody],
         "CertificateArn": str,
         "CertificateOwner": str,
         "ValidFromDate": datetime,
